﻿using Ch20.Models;
using System;
using System.Collections.Generic;
using System.Runtime.Caching;
using System.Web.Services;
using System.Web.UI;

namespace Ch20
{
    public partial class DefaultAngular : Page
    {
        public static List<Artist> ArtistCache
        {
            get { return (List<Artist>)MemoryCache.Default.Get("artists"); }
            set { MemoryCache.Default.Set("artists", value, ObjectCache.InfiniteAbsoluteExpiration); }
        }

        protected void Page_Load(object sender, EventArgs e)
        {
            if (!IsPostBack)
            {
                if (ArtistCache == null)
                {
                    ArtistCache = new List<Artist>();
                }
            }
        }

        [WebMethod]
        public static string AddArtist(string artistName, string rating)
        {
            if (string.IsNullOrEmpty(artistName))
            {
                return "Invalid artist name: cannot be empty.";
            }

            if (string.IsNullOrEmpty(rating))
            {
                return "Invalid artist rating: cannot be empty.";
            }
            
            int ratingNum;
            if (!int.TryParse(rating, out ratingNum))
            {
                return "Invalid artist rating: must be a number.";
            }

            ArtistCache.Add(new Artist {
                Id = Guid.NewGuid(),
                Name = artistName,
                Rating = ratingNum
            });

            return null;
        }

        [WebMethod]
        public static List<Artist> GetArtists()
        {
            return ArtistCache;
        }
    }
}